Check
-----

Problematic
^^^^^^^^^^^

How can we efficiently check the syntax of IP, domains, and URL?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.check
   :members:
   :private-members:

